Property Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

G |
| grid, jqPlot
| gridLineColor, Grid
| gridLineWidth, Grid
| groups, $.jqplot.BarRenderer
H |
| hideZeros, $.jqplot.PointLabels
| highlightAlpha, $.jqplot.BubbleRenderer
| highlightColor, $.jqplot.LineRenderer
| highlightColors Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| highlightMouseDown Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer
| highlightMouseOver Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer
| hlc, $.jqplot.OHLCRenderer
| hubRadius, $.jqplot.MeterGaugeRenderer
I |
| index, Series
| innerDiameter, $.jqplot.DonutRenderer
| insertBreaks, $.jqplot.BlockRenderer
| intersectionThreshold, $.jqplot.Cursor
| interval, $.jqplot.LineRenderer
| intervalColors, $.jqplot.MeterGaugeRenderer
| intervalInnerRadius, $.jqplot.MeterGaugeRenderer
| intervalOuterRadius, $.jqplot.MeterGaugeRenderer
| intervals, $.jqplot.MeterGaugeRenderer
| isarc $.jqplot.shadowRenderer$.jqplot.shapeRenderer
| isMinorTick $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
L |
| label $.jqplot.AxisLabelRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.MeterGaugeRenderer$.jqplot.Trendline Axis Series
| labelHeightAdjust, $.jqplot.MeterGaugeRenderer
| labelOptions, Axis
| labelPosition $.jqplot.CanvasAxisTickRenderer$.jqplot.MeterGaugeRenderer
| labelRenderer, Axis
| labels $.jqplot.PointLabels Legend
| labelsFromSeries, $.jqplot.PointLabels
| legend, jqPlot
| lineCap $.jqplot.CanvasOverlay$.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| lineJoin $.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| linePattern $.jqplot.shapeRenderer Series
| lineWidth $.jqplot.CanvasOverlay$.jqplot.FunnelRenderer$.jqplot.MarkerRenderer$.jqplot.OHLCRenderer$.jqplot.shadowRenderer$.jqplot.Trendline Series
| lineWidthAdjust, $.jqplot.Highlighter
| location $.jqplot.PointLabels Legend
| looseZoom, $.jqplot.Cursor

> this.grid = new Grid()

See Grid for grid specific options.

> this.gridLineColor = '#cccccc'

color of the grid lines.

> this.gridLineWidth = 1.0

width of the grid lines.

> this.groups = 1

group bars into this many groups

> this.hideZeros = false

true to not show a label for a value which is 0.

> this.highlightAlpha = null

Alpha transparency to apply when highlighting bubble.

> this.highlightColor = null

color to use when highlighting an area on a filled plot.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightColors = []

an array of colors to use when highlighting a bar.

> this.highlightColors = []

An array of colors to use when highlighting a slice.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightColors = []

array of colors to use when highlighting an area.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a bubble.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a area.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over an area on a filled plot.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight bubbles when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight area when moused over.

> this.highlightMouseOver = true

True to highlight area on a filled plot when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.hlc = false

true if is a hi-low-close chart (no open price).

> this.hubRadius = null

Radius of the hub at the bottom center of gauge which the needle attaches to.

> this.index

0 based index of this series in the plot series array.

> this.innerDiameter = null

Inner diameter of the donut, auto calculated by default.

> this.insertBreaks = true

true to turn spaces in data block label into html breaks br /.

> this.intersectionThreshold = 2

pixel distance from data point or marker to consider cursor lines intersecting with point.

> interval: '3%' }

User specified interval above and below line for bands [default: ‘3%’’].

> this.intervalColors = [ "#4bb2c5", "#EAA228", "#c5b47f", "#579575", "#839557", "#958c12", "#953579", "#4b5de4", "#d8b83f", "#ff5800", "#0085cc", "#c747a3", "#cddf54", "#FBD178", "#26B4E3", "#bd70c7"]

Array of colors to use for the intervals.

> this.intervalInnerRadius = null

Radius of the inner circle of the interval ring.

> this.intervalOuterRadius = null

Radius of the outer circle of the interval ring.

> this.intervals = []

Array of ranges to be drawn around the gauge.

> this.isarc = false

whether the shadow is an arc or not.

> this.isarc = false

whether the shadow is an arc or not.

> this.isMinorTick = false

if this is a minor tick.

> this.isMinorTick = false

if this is a minor tick.

> this.label = ''

The text or html for the label.

> this.label = ''

label for the axis.

> this.label = null

A gauge label like ‘kph’ or ‘Volts’

> this.label = ''

Label for the trend line to use in the legend.

> this.label = null

Label for the axis

> this.label = ''

Line label to use in the legend.

> this.labelHeightAdjust = 0

Number of Pixels to offset the label up (-) or down (+) from its default position.

> this.labelOptions = {}

Options passed to the label renderer.

> this.labelPosition = 'auto'

‘auto’, ‘start’, ‘middle’ or ‘end’.

> this.labelPosition = 'inside'

Where to position the label, either ‘inside’ or ‘bottom’.

> this.labelRenderer = $.jqplot.AxisLabelRenderer

A class of a rendering engine for creating an axis label.

> this.labels = []

array of arrays of labels, one array for each series.

> this.labels = []

Array of labels to use.

> this.labelsFromSeries = false

true to use labels within data point arrays.

> this.legend = new Legend()

see $.jqplot.TableLegendRenderer
Type of ending placed on the line [‘round’, ‘butt’, ‘square’]

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.lineCap = 'round'

Canvas lineCap style at ends of line.

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineJoin = 'round'

Canvas lineJoin style between segments of series.

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’
Width of the line.

> this.lineWidth = 2

width of line if areas are stroked and not filled.

> this.lineWidth = 2

size of the line for non-filled markers.

> this.lineWidth = 1.5

Width of the hi-low line and open/close ticks.

> this.lineWidth = 1.5

width of the shadow line stroke.

> this.lineWidth = 1.5

Width of the trend line.

> this.lineWidth = 2.5

width of the line in pixels.

> this.lineWidthAdjust = 2.5

Pixels to add to the lineWidth of the highlight.

> this.location = 'n'

compass location where to position the label around the point.

> this.location = 'ne'

Placement of the legend.

> this.looseZoom = true

Will expand zoom range to provide more rounded tick values.
Close